@@ -4,7 +4,11 @@
 # calculation of item fit for one item
 .calc.itemfit.oneitem <- function( ii , pjk , pi.k , P1 , I , Eik_min ,
          sumscore.distribution , scoredistribution , data , sumscore ){
-    scored.ii <- .calc.scoredistribution.cdm( pjk[,-ii,] )
+#    scored.ii <- .calc.scoredistribution.cdm( pjk[,-ii,] )
+	pjk.ii <- pjk[,-ii,]	
+    P1ii <- pjk.ii[,,2]
+    Q1ii <- pjk.ii[,,1]
+	scored.ii <- .Call("calc_scoredistribution_cdm" , P1ii , Q1ii , PACKAGE="CDM")
     eik_t2 <- colSums( scoredistribution * pi.k )
     eik_t1 <- c(0,colSums( P1[,ii] * scored.ii * pi.k  ) )
 	# P1 is the probability of passing the item
