@@ -3,7 +3,11 @@
 ################################################################################
 print.mcdina <-
 function(x, ... ){
-	cat("Estimation of multiple choice DINA model\n")
+	cat("Estimation of multiple choice DINA model\n\n")
+	
+    d1 <- utils::packageDescription("CDM")
+	cat( paste( d1$Package , " " , d1$Version , " (" , d1$Date , ")" , sep="") , "\n" )	
+	
 	cat("\nCall:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"), 
 				"\n\n", sep = "")
 	#*** parameters
@@ -13,8 +17,8 @@ function(x, ... ){
 	cat(paste0("Number of skill dimensions = " , ncol(x$q.matrix) - 2, "\n") )	
 	cat(paste0("Number of skill classes = " , nrow(x$attribute.patt) , "\n") )		
 	cat(paste0("Number of parameters = " , x$Npars , "\n") )
-	cat(paste0("  Number of item parameters = " , x$ic$itempars , "\n") )
-	cat(paste0("  Number of skill distribution parameters = " , 
+	cat(paste0("  # item parameters = " , x$ic$itempars , "\n") )
+	cat(paste0("  # skill distribution parameters = " , 
 				x$ic$traitpars , "\n") )
 	#*** likelihood
 	cat( paste0( "\nLog-Likelihood = " , round( x$loglike ,2 ) , "\n") )
